# DON'T EDIT MANNUALLY! THIS FILE IS GENERATED BY author/create_ddl.pl
package Ukigumo::Server::DB::Schema;
use strict;
use warnings;
use DBI qw/:sql_types/;
use Teng::Schema::Declare;

table {
    name 'branch';
    pk   qw/branch_id/;
    columns
        { name => 'branch_id', type => SQL_INTEGER }, # INTEGER
        { name => 'project', type => SQL_VARCHAR }, # VARCHAR
        { name => 'branch', type => SQL_VARCHAR }, # VARCHAR
        { name => 'last_report_id', type => SQL_INTEGER }, # INTEGER
        { name => 'ctime', type => SQL_INTEGER }, # INTEGER
    ;
};

table {
    name 'report';
    pk   qw/report_id/;
    columns
        { name => 'report_id', type => SQL_INTEGER }, # INTEGER
        { name => 'branch_id', type => SQL_INTEGER }, # INTEGER
        { name => 'status', type => SQL_TINYINT }, # TINYINT
        { name => 'repo', type => SQL_LONGVARCHAR }, # TEXT
        { name => 'revision', type => SQL_VARCHAR }, # VARCHAR
        { name => 'vc_log', type => SQL_LONGVARCHAR }, # TEXT
        { name => 'body', type => SQL_LONGVARCHAR }, # TEXT
        { name => 'ctime', type => SQL_INTEGER }, # INTEGER
        { name => 'compare_url', type => SQL_VARCHAR }, # VARCHAR
        { name => 'elapsed_time_sec', type => SQL_INTEGER }, # INTEGER
    ;
};

1;
